pub struct Check {
pub system: String,
pub href: Option<String>,
pub value: String,
}Expand description
The CheckType complex type is used to define an element to hold information about an individual check. It includes a checking system specification URI, string content, and an optional external file reference. The checking system specification should be the URI for a particular version of OVAL or a related system testing language, and the content will be an identifier of a test written in that language. The external file reference could be used to point to the file in which the content test identifier is defined.
Fields
system: Stringhref: Option<String>value: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Check
impl<'de> Deserialize<'de> for Check
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl StructuralPartialEq for Check