Generator

Struct Generator 

pub struct Generator {
    pub product_name: String,
    pub product_version: String,
    pub schema_version: String,
    pub timestamp: DateTime<Utc>,
}
The GeneratorType complex type defines an element that is used to hold information about when a particular document was compiled, what version of the schema was used, what tool compiled the document, and what version of that tool was used. Additional generator information is also allowed although it is not part of the official schema. Individual organizations can place generator information that they feel is important and it will be skipped during the validation. All that this schema really cares about is that the stated generator information is there.

Fields

product_name: String

The optional product_name element specifies the name of the application used to generate the file.

product_version: String

The optional product_version element specifies the version of the application used to generate the file.

schema_version: String

The required schema_version element specifies the version of the schema that the document has been written against and that should be used for validation.

timestamp: DateTime<Utc>

The required timestamp element specifies when the particular document was compiled. The format for the timestamp is yyyy-mm-ddThh:mm:ss. Note that the timestamp element does not specify when an item in the document was created or modified but rather when the actual XML document that contains the items was created. For example, a document might pull a bunch of existing items together, each of which was created at some point in the past. The timestamp in this case would be when this combined document was created.