Notes

Struct Notes 

pub struct Notes {
    pub lang: String,
    pub value: String,
}
The NotesType complex type defines an element that consists of one or more child note elements. It is assumed that each of these note elements is representative of the same language as defined by their parent.

Fields

lang: Stringvalue: String