pub struct Reference {
pub href: String,
pub value: String,
}Expand description
The ReferencesType complex type defines an element used to hold a collection of individual references. Each reference consists of a piece of text (intended to be human-readable) and a URI (intended to be a URL, and point to a real resource) and is used to point to extra descriptive material, for example a supplier’s web site or platform documentation.
Fields
href: Stringvalue: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Reference
impl<'de> Deserialize<'de> for Reference
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more