pub struct Notes {
pub lang: String,
pub value: String,
}Expand description
The NotesType complex type defines an element that consists of one or more child note elements. It is assumed that each of these note elements is representative of the same language as defined by their parent.
Fields
lang: Stringvalue: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Notes
impl<'de> Deserialize<'de> for Notes
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more